/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */

import { Injectable } from '@angular/core';
import {StorageService} from "../../shared/storage/storage.service";
import {defaultSortOrder} from "../components/active-capability-requests/active-capability-requests.component";

@Injectable({
  providedIn: 'root'
})
export class ActiveRequestsService {

  public sortOrderKey: string = "reqIdSortOrder";
  private currentSortOrder: string;

  constructor(private storage: StorageService) {
    this.storage = storage;
    this.currentSortOrder = this.storage.getLocal(this.sortOrderKey) === undefined ? defaultSortOrder : this.storage.getLocal(this.sortOrderKey)
    if (!!this.currentSortOrder) {
      this.currentSortOrder = defaultSortOrder
    }
  }

  public saveReqIdSortOrder(sortOrder: string) {
    this.currentSortOrder = sortOrder;
    this.storage.saveLocal(this.sortOrderKey, sortOrder);

  }

  public getSortOrder(): string {
    return this.storage.getLocal(this.sortOrderKey);
  }
}
